

l_offer_text2 = {
    'ru': "✏️ 1/4. Напиши мне <b>текст</b> для нового оффера (не забудь использовать <i>форматирование</i>)\n\n(<i>или нажми «➡️️/Next», чтобы пропустить этот шаг</i>)",
    'en': "✏️ 1/4. Send me <b>text</b> for new post for (don't forget to use <i>formatting</i>)\n\n(<i>or click the «➡️️/Next» to skip this step</i>)",
    'es': "✏️ 1/4. Envíame <b>texto</b> para una nueva publicación (no olvides usar <i>formato</i>)\n\n(<i>o haz clic en «➡️️ /Next» para omitir este paso</i>)",
    'fr': "✏️ 1/4. Envoyez-moi un <b>texte</b> pour un nouveau message (n'oubliez pas d'utiliser le <i>formatage</i>)\n\n(<i>ou cliquez sur le «➡️️ /Next» pour ignorer cette étape</i>)",
    'zh': "✏️ 1/4. 給我 <b>文本</b> 對於新職位 (不要忘記使用 <i>格式化</i>)\n\n(<i>或單擊 «➡️️/Next» 跳過這一步</i>)",
    'ar': "✏️ 1/3. أرسل لي <b> نصًا </b> للنشر الجديد إلى عن على (لا تنس استخدام <i> تنسيق </i>) \n\n (<i> أو انقر فوق« ➡️️ /Next التالي »لتخطي هذه الخطوة </i>)",
}